@@ -24,7 +24,7 @@ from .utils.selenium_core import SeleniumDriverCore
 
 class SmartDriver(SeleniumDriverCore):
     def __init__(self, driver, api_key, initialization_dict={}):
-        self.version = 'appium-0.1.23'
+        self.version = 'appium-0.1.22'
         self.root_elem = None
         caps = driver.desired_capabilities
         self.automation_name = caps.get('automationName', '')
@@ -37,8 +37,7 @@ class SmartDriver(SeleniumDriverCore):
         screenshotBase64 = self._get_screenshot()
         im = Image.open(io.BytesIO(base64.b64decode(screenshotBase64)))
         width, height = im.size
-        self.multiplier = max(1.0, 1.0 * width / window_size['width'])
-        log.debug(f'Multiplier: {self.multiplier}')
+        self.multiplier = 1.0 * width / window_size['width']
         self.is_espresso = self.automation_name.lower() == 'espresso'
         self.is_ios = self.automation_name.lower() == 'xcuitest'
 
@@ -158,7 +157,7 @@ class SmartDriver(SeleniumDriverCore):
         iou_scores = []
         for element in elements:
             iou_scores.append(self._iou_boxes(new_box, element.rect))
-        composite = sorted(zip(iou_scores, elements), reverse=True, key=lambda x: x[0])
+        iou_composite = sorted(zip(iou_scores, elements), reverse=True, key=lambda x: x[0])
         # Pick the best match
         """
         We have to be smart about element selection here because of clicks being intercepted and what not, so we basically
@@ -166,7 +165,7 @@ class SmartDriver(SeleniumDriverCore):
         they are a valid candidate. If none of them is of type input, we pick the one with maxIOU, otherwise we pick the input type,
         which is 90% of test cases.
         """
-        composite = filter(lambda x: x[0] > 0, composite)
+        composite = filter(lambda x: x[0] > 0, iou_composite)
         composite = list(filter(lambda x: self._center_hit(new_box, x[1].rect), composite))
 
         attribute_for_class = "className"
@@ -195,7 +194,7 @@ class SmartDriver(SeleniumDriverCore):
             for score, element in composite:
                 if element.tag_name == 'input' or element.tag_name == 'button':
                     return element
-            return composite[0][1]
+            return iou_composite[0][1]
 
 
 class ai_elem(webdriver.webelement.WebElement):
